#
# Copyright 2018 Fairphone B.V.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""Main entry point of the Android Maestro module."""

import argparse
import sys


from . import log
from .shell import MaestroShell


def cmdline_args():
    """Define and parse command line arguments.

    Returns:
        The populated `argparse.Namespace` from the command line arguments.

    """
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "-l",
        "--log",
        default=sys.stderr,
        type=argparse.FileType("w"),
        help="Log file. Default: stderr.",
    )
    parser.add_argument(
        "-v",
        "--verbose",
        default=0,
        action="count",
        help="Increase log level verbosity. May be used several times.",
    )
    parser.add_argument(
        "-q",
        "--quiet",
        default=0,
        action="count",
        help="Decrease log level verbosity. May be used several times.",
    )

    return parser.parse_args()


def main():
    """Execute the Android Maestro in a standalone fashion.

    The command line arguments are parsed to create the logging facility. The
    :py:class:`.shell.MaestroShell` is then executed.

    """
    args = cmdline_args()
    log.configure_logger("", args.log, args.verbose, args.quiet)
    shell = MaestroShell()
    shell.cmdloop()


if __name__ == "__main__":
    main()
